"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Rect = void 0;
var _data = require("./data.js");
var _util = require("./util.js");
/**
 * Rect object.
 */
class Rect extends _data.Data {
  /**
   * Minimum X.
   */
  xMin = 0;

  /**
   * Maximum X.
   */
  xMax = 0;

  /**
   * Minimum Y.
   */
  yMin = 0;

  /**
   * Maximum Y.
   */
  yMax = 0;

  /**
   * Rect constructor.
   */
  constructor() {
    super();
  }

  /**
   * Number of bits need to encode the values.
   *
   * @returns Bit count.
   */
  get nBits() {
    return Math.max((0, _util.bitCountS)(this.xMin), (0, _util.bitCountS)(this.xMax), (0, _util.bitCountS)(this.yMin), (0, _util.bitCountS)(this.yMax));
  }

  /**
   * @inheritdoc
   */
  get size() {
    return (0, _util.bitCountToBytes)(5 + this.nBits * 4);
  }

  /**
   * @inheritdoc
   */
  encoder(data) {
    const {
      nBits
    } = this;
    const bW = (0, _util.bitWriter)(data, 0);
    let b = 0;
    bW(nBits, 5, b);
    b += 5;
    for (const value of [this.xMin, this.xMax, this.yMin, this.yMax]) {
      bW(value, nBits, b);
      b += nBits;
    }
    const over = b % 8;
    if (over) {
      bW(0, 8 - over, b);
    }
  }
}
exports.Rect = Rect;
//# sourceMappingURL=rect.js.map