"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Tag = void 0;
var _data = require("./data.js");
/**
 * Tag object.
 */
class Tag extends _data.Data {
  /**
   * Tag code.
   */
  code = 0;

  /**
   * Tag data.
   */
  data = new Uint8Array(0);

  /**
   * Tag constructor.
   */
  constructor() {
    super();
  }

  /**
   * Is the tag a long tag.
   *
   * @returns True if long tag.
   */
  get long() {
    return this.data.length >= 0b111111;
  }

  /**
   * @inheritdoc
   */
  get size() {
    return 2 + (this.long ? 4 : 0) + this.data.length;
  }

  /**
   * @inheritdoc
   */
  encoder(data) {
    let i = 0;
    const {
      code,
      data: d,
      long
    } = this;
    // eslint-disable-next-line no-bitwise
    const head = code << 6 | (long ? 0b111111 : d.length);
    const v = new DataView(data.buffer, data.byteOffset, data.byteLength);
    v.setUint16(i, head, true);
    i += 2;
    if (long) {
      v.setUint32(i, d.length, true);
      i += 4;
    }
    data.set(d, i);
  }
}
exports.Tag = Tag;
//# sourceMappingURL=tag.js.map