"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PatchPath = void 0;
var _data = require("../data.js");
var _patch = require("./patch.js");
/**
 * PatchPath object.
 * Patch broken Linux projector path code.
 * Replaces bad "file:" prefix with "file://" for projector self URL.
 */
class PatchPath extends _patch.Patch {
  /**
   * Get a remapped pointer, if pointer needs remapping.
   *
   * @param ptr Current pointer.
   * @returns Remapped pointer or null.
   */
  _getRemap(ptr) {
    const str = this._readCstr(ptr);
    if (str !== 'file:') {
      return null;
    }
    const shdr = this._theShdrForAddress(ptr);
    const data = new Uint8Array(shdr.data);
    const strd = new TextEncoder().encode('\0file://\0');
    const fileI = (0, _data.findIndex)(data, strd) + 1;
    if (!fileI) {
      return null;
    }
    return this._elf.bits === 64 ? shdr.shAddr + BigInt(fileI) : shdr.shAddr + fileI;
  }
}
exports.PatchPath = PatchPath;
//# sourceMappingURL=path.js.map