import { Bundle } from '../bundle.ts';
import { ProjectorHtml } from '../projector/html.ts';
/**
 * BundleHtml object.
 */
export declare class BundleHtml extends Bundle {
    /**
     * ProjectorHtml instance.
     */
    readonly projector: ProjectorHtml;
    /**
     * BundleHtml constructor.
     *
     * @param path Output path.
     * @param flat Flat bundle.
     */
    constructor(path: string, flat?: boolean);
    /**
     * Main application file extension.
     *
     * @returns File extension.
     */
    get extension(): string;
    /**
     * Get the nested subdirectory.
     *
     * @returns Directory name.
     */
    get subdir(): string;
    /**
     * Get the nested index.
     *
     * @returns File name.
     */
    get index(): string;
    /**
     * Get launcher HTML code.
     *
     * @returns HTML code.
     */
    getLauncher(): string;
    /**
     * @inheritdoc
     */
    protected _close(): Promise<void>;
    /**
     * @inheritdoc
     */
    protected _getProjectorPathNested(): string;
    /**
     * Create projector instance for the bundle.
     *
     * @returns Projector instance.
     */
    protected _createProjector(): ProjectorHtml;
    /**
     * Write the launcher file.
     */
    protected _writeLauncher(): Promise<void>;
}
