import { NtExecutable } from '@shockpkg/resedit';
/**
 * Get the EXE section that includes an address.
 *
 * @param exe NtExecutable instance.
 * @param address The address.
 * @returns The section or null if section not found.
 */
export declare function exeSectionByAddress(exe: NtExecutable, address: number): {
    info: {
        virtualAddress: number;
    };
    data: ArrayBuffer | null;
} | null;
/**
 * Get the EXE code section.
 *
 * @param exe NtExecutable instance.
 * @returns The section.
 */
export declare function exeCodeSection(exe: NtExecutable): {
    info: {
        virtualAddress: number;
    };
    data: ArrayBuffer;
};
/**
 * Assert the given section is last section.
 *
 * @param exe NtExecutable instance.
 * @param index ImageDirectory index.
 * @param name Friendly name for messages.
 */
export declare function exeAssertLastSection(exe: NtExecutable, index: number, name: string): void;
/**
 * Removes the reloc section if exists, fails if not the last section.
 *
 * @param exe NtExecutable instance.
 * @returns Restore function.
 */
export declare function exeRemoveReloc(exe: NtExecutable): () => void;
/**
 * Update the sizes in EXE headers.
 *
 * @param exe NtExecutable instance.
 */
export declare function exeUpdateSizes(exe: NtExecutable): void;
