/**
 * Linux projector patch.
 */
export interface ILinuxProjectorPatch {
    /**
     * Attempt to replace the window title if not null.
     *
     * @default null
     */
    patchWindowTitle?: string | null;
    /**
     * Attempt to patch out application menu.
     *
     * @default false
     */
    patchMenuRemove?: boolean;
    /**
     * Attempt to patch the projector path reading code.
     *
     * @default false
     */
    patchProjectorPath?: boolean;
    /**
     * Attempt to patch the projector offset reading code.
     *
     * @default false
     */
    patchProjectorOffset?: boolean;
}
/**
 * Apply patches to projector.
 *
 * @param elf Projector data.
 * @param options Patch options.
 * @returns Patched projector.
 */
export declare function linuxProjectorPatch(elf: Readonly<Uint8Array>, options: Readonly<ILinuxProjectorPatch>): Uint8Array;
/**
 * Get Linux launcher for the specified type.
 *
 * @param type Executable type.
 * @returns Launcher data.
 */
export declare function linuxLauncher(type: 'i386' | 'x86_64'): Promise<Uint8Array>;
