/**
 * Windows projector patch.
 */
export interface IWindowsProjectorPatch {
    /**
     * Replace icons if not null.
     *
     * @default null
     */
    iconData?: Readonly<Uint8Array> | null;
    /**
     * Replace version strings if not null.
     *
     * @default null
     */
    versionStrings?: Readonly<{
        [key: string]: string;
    }> | null;
    /**
     * Remove signature if present and true.
     *
     * @default false
     */
    removeCodeSignature?: boolean;
    /**
     * Attempt to replace Windows window title if not null.
     *
     * @default null
     */
    patchWindowTitle?: string | null;
    /**
     * Attempt to disable the out-of-date check if true.
     *
     * @default false
     */
    patchOutOfDateDisable?: boolean;
}
/**
 * Apply patches to projector.
 *
 * @param data Projector data.
 * @param options Patch options.
 * @returns Patched projector.
 */
export declare function windowsProjectorPatch(data: Readonly<Uint8Array>, options: Readonly<IWindowsProjectorPatch>): Uint8Array;
/**
 * Get Windows launcher for the specified type.
 *
 * @param type Executable type.
 * @param resources Data to optionally copy resources from.
 * @returns Launcher data.
 */
export declare function windowsLauncher(type: 'i686' | 'x86_64', resources?: (() => Promise<Uint8Array>) | null): Promise<Uint8Array>;
