import { Data } from "./data.mjs";

/**
 * Fixed8 object.
 */
export class Fixed8 extends Data {
  /**
   * Float numerator.
   */
  numerator = 0;

  /**
   * Float denominator.
   */
  denominator = 0;

  /**
   * Fixed8 constructor.
   */
  constructor() {
    super();
  }

  /**
   * @inheritdoc
   */
  get size() {
    return 2;
  }

  /**
   * Value.
   *
   * @param value The value.
   */
  set value(value) {
    const i16 = Math.floor(value * 256);
    // eslint-disable-next-line no-bitwise
    this.numerator = i16 >> 8 & 0xff;
    // eslint-disable-next-line no-bitwise
    this.denominator = i16 & 0xff;
  }

  /**
   * Value.
   *
   * @returns The value.
   */
  get value() {
    // eslint-disable-next-line no-bitwise
    const i16 = this.numerator << 8 | this.denominator;
    return i16 / 256;
  }

  /**
   * @inheritdoc
   */
  encoder(data) {
    data[0] = this.denominator;
    data[1] = this.numerator;
  }
}
//# sourceMappingURL=fixed8.mjs.map