import { Data } from "./data.mjs";
import { Rect } from "./rect.mjs";
import { Fixed8 } from "./fixed8.mjs";
/**
 * Swf object.
 */
export class Swf extends Data {
  /**
   * Format version.
   */
  version = 0;

  /**
   * Frame size.
   */
  frameSize = new Rect();

  /**
   * Frame rate.
   */
  frameRate = new Fixed8();

  /**
   * Frame count.
   */
  frameCount = 0;

  /**
   * Movie tags.
   */
  tags = [];

  /**
   * Swf constructor.
   */
  constructor() {
    super();
  }

  /**
   * @inheritdoc
   */
  get size() {
    return this.tags.reduce((v, t) => t.size + v, 3 + 1 + 4 + this.frameSize.size + this.frameRate.size + 2);
  }

  /**
   * @inheritdoc
   */
  encoder(data) {
    let i = 0;
    data[i++] = 0x46;
    data[i++] = 0x57;
    data[i++] = 0x53;
    data[i++] = this.version;
    const v = new DataView(data.buffer, data.byteOffset, data.byteLength);
    v.setUint32(i, this.size, true);
    i += 4;
    i += this.frameSize.encode(data, i).length;
    i += this.frameRate.encode(data, i).length;
    v.setUint16(i, this.frameCount, true);
    i += 2;
    for (const tag of this.tags) {
      i += tag.encode(data, i).length;
    }
  }
}
//# sourceMappingURL=swf.mjs.map