import { findIndex } from "../data.mjs";
import { Patch } from "./patch.mjs";

/**
 * PatchPath object.
 * Patch broken Linux projector path code.
 * Replaces bad "file:" prefix with "file://" for projector self URL.
 */
export class PatchPath extends Patch {
  /**
   * Get a remapped pointer, if pointer needs remapping.
   *
   * @param ptr Current pointer.
   * @returns Remapped pointer or null.
   */
  _getRemap(ptr) {
    const str = this._readCstr(ptr);
    if (str !== 'file:') {
      return null;
    }
    const shdr = this._theShdrForAddress(ptr);
    const data = new Uint8Array(shdr.data);
    const strd = new TextEncoder().encode('\0file://\0');
    const fileI = findIndex(data, strd) + 1;
    if (!fileI) {
      return null;
    }
    return this._elf.bits === 64 ? shdr.shAddr + BigInt(fileI) : shdr.shAddr + fileI;
  }
}
//# sourceMappingURL=path.mjs.map